@@ -8,13 +8,13 @@
 #'
 #' @param dots Whether to use dots instead of dashes in the version
 #'   number.
-#' @return A data frame with three chracter columns: \sQuote{version},
+#' @return A data frame with three columns: \sQuote{version},
 #'   \sQuote{date} and \sQuote{nickname}.
 #'
 #' @export
 #' @importFrom curl new_handle handle_setheaders curl_fetch_memory
 #' @importFrom xml2 read_xml xml_find_all xml_ns xml_find_first xml_text
-#' @examples
+#' @examplesIf rversions:::is_online()
 #' r_versions()
 
 r_versions <- function(dots = TRUE) {
@@ -25,8 +25,10 @@ r_versions <- function(dots = TRUE) {
   nicks <- cached_nicks()
   nonick <- setdiff(dotver, names(nicks))
   if (length(nonick)) nicks <- c(nicks, get_nicknames(nonick))
-  
-  df$date <- strptime(df$date, "%Y-%m-%dT%H:%M:%S", tz = "UTC")
+
+  df$date <- as.POSIXct(
+    strptime(df$date, "%Y-%m-%dT%H:%M:%S", tz = "UTC")
+  )
 
   df$nickname <- rep(NA_character_, nrow(df))
   df$nickname[match(names(nicks), dotver)] <- nicks
@@ -44,7 +46,7 @@ r_versions <- function(dots = TRUE) {
 #'
 #' @export
 #' @importFrom utils tail
-#' @examples
+#' @examplesIf rversions:::is_online()
 #' r_release()
 
 r_release <- function(dots = TRUE) {
@@ -63,7 +65,7 @@ r_release <- function(dots = TRUE) {
 #'
 #' @export
 #' @importFrom utils tail
-#' @examples
+#' @examplesIf rversions:::is_online()
 #' r_oldrel()
 
 r_oldrel <- function(dots = TRUE) {
